@@ -3,8 +3,7 @@ import sys
 from unittest import TestCase
 from unittest.mock import patch, MagicMock
 
-from dagger import DaggerAPI, initDagger, initLambda
-from dagger.constants import DAGGER_URL
+from dagger import initDagger, wrap
 
 @patch('dagger.DaggerAPI.requests')
 class DaggerTestCase(TestCase):
@@ -37,5 +36,4 @@ class DaggerTestCase(TestCase):
 
         mock_request_handler.assert_called_once_with(mock_event, mock_context)
 
-        assert len(mock_api.return_value.createTask.mock_calls) == 2
-        assert len(mock_api.return_value.createTask.return_value.update.mock_calls) == 1
+        assert len(mock_api.return_value.registerTask.mock_calls) == 1
